# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Dict, Optional

from pydantic.v1 import Field, StrictStr

from earnix_elevate.clients.imx.models.connection_response import ConnectionResponse
from earnix_elevate.clients.imx.models.o_auth_response import OAuthResponse
from earnix_elevate.clients.imx.models.user import User


class PriceItDimConnectionResponse(ConnectionResponse):
    """
    `PriceItDimConnectionResponse`

    Response for a Price-It Dim Connection that provides access to Price-It, including authentication details and connection settings.
    """

    type_mapping: Optional[Dict[str, StrictStr]] = Field(
        default=None,
        alias="typeMapping",
        description="JSON object mapping source columns to target types in price-it. Keys are source column names, values are target types values in price-it.",
    )
    type_mapping_name: Optional[StrictStr] = Field(
        default=None,
        alias="typeMappingName",
        description="Optional name/label for the type mapping configuration.",
    )
    auth: Optional[OAuthResponse] = None
    __properties = [
        "read",
        "write",
        "id",
        "lockVersion",
        "name",
        "description",
        "tags",
        "createdBy",
        "createdDate",
        "lastModifiedBy",
        "lastModifiedDate",
        "type",
        "typeMapping",
        "typeMappingName",
        "auth",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PriceItDimConnectionResponse:
        """Create an instance of PriceItDimConnectionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict["createdBy"] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of last_modified_by
        if self.last_modified_by:
            _dict["lastModifiedBy"] = self.last_modified_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of auth
        if self.auth:
            _dict["auth"] = self.auth.to_dict()
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict["description"] = None

        # set to None if type_mapping (nullable) is None
        # and __fields_set__ contains the field
        if self.type_mapping is None and "type_mapping" in self.__fields_set__:
            _dict["typeMapping"] = None

        # set to None if type_mapping_name (nullable) is None
        # and __fields_set__ contains the field
        if (
            self.type_mapping_name is None
            and "type_mapping_name" in self.__fields_set__
        ):
            _dict["typeMappingName"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PriceItDimConnectionResponse:
        """Create an instance of PriceItDimConnectionResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PriceItDimConnectionResponse.parse_obj(obj)

        _obj = PriceItDimConnectionResponse.parse_obj(
            {
                "read": obj.get("read") if obj.get("read") is not None else True,
                "write": obj.get("write") if obj.get("write") is not None else False,
                "id": obj.get("id"),
                "lock_version": obj.get("lockVersion"),
                "name": obj.get("name"),
                "description": obj.get("description"),
                "tags": obj.get("tags"),
                "created_by": User.from_dict(obj.get("createdBy"))
                if obj.get("createdBy") is not None
                else None,
                "created_date": obj.get("createdDate"),
                "last_modified_by": User.from_dict(obj.get("lastModifiedBy"))
                if obj.get("lastModifiedBy") is not None
                else None,
                "last_modified_date": obj.get("lastModifiedDate"),
                "type": obj.get("type"),
                "type_mapping": obj.get("typeMapping"),
                "type_mapping_name": obj.get("typeMappingName"),
                "auth": OAuthResponse.from_dict(obj.get("auth"))
                if obj.get("auth") is not None
                else None,
            }
        )
        return _obj
