# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
import re
from typing import Optional

from pydantic.v1 import Field, constr, validator

from earnix_elevate.clients.imx.models.merge_connection_request import (
    MergeConnectionRequest,
)
from earnix_elevate.clients.imx.models.s3_auth_request import S3AuthRequest


class MergeS3ConnectionRequest(MergeConnectionRequest):
    """
    `MergeS3ConnectionRequest`

    Request to partially update an S3 Connection, allowing selective modification of authentication credentials, endpoint configuration, and path restrictions.
    """

    path_restriction: Optional[constr(strict=True, max_length=1000)] = Field(
        default=None,
        alias="pathRestriction",
        description="Optional path restriction to limit access to specific paths within the S3 bucket",
    )
    auth: Optional[S3AuthRequest] = None
    __properties = [
        "id",
        "lockVersion",
        "name",
        "description",
        "tags",
        "type",
        "pathRestriction",
        "auth",
    ]

    @validator("path_restriction")
    def path_restriction_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(
            r"^(s3:\/\/)?([a-z0-9][a-z0-9.-]{1,61}[a-z0-9]|[a-z0-9]{3})(\/\S*)?$", value
        ):
            raise ValueError(
                r"must validate the regular expression /^(s3:\/\/)?([a-z0-9][a-z0-9.-]{1,61}[a-z0-9]|[a-z0-9]{3})(\/\S*)?$/"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MergeS3ConnectionRequest:
        """Create an instance of MergeS3ConnectionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of auth
        if self.auth:
            _dict["auth"] = self.auth.to_dict()
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict["description"] = None

        # set to None if path_restriction (nullable) is None
        # and __fields_set__ contains the field
        if self.path_restriction is None and "path_restriction" in self.__fields_set__:
            _dict["pathRestriction"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MergeS3ConnectionRequest:
        """Create an instance of MergeS3ConnectionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MergeS3ConnectionRequest.parse_obj(obj)

        _obj = MergeS3ConnectionRequest.parse_obj(
            {
                "id": obj.get("id"),
                "lock_version": obj.get("lockVersion"),
                "name": obj.get("name"),
                "description": obj.get("description"),
                "tags": obj.get("tags"),
                "type": obj.get("type"),
                "path_restriction": obj.get("pathRestriction"),
                "auth": S3AuthRequest.from_dict(obj.get("auth"))
                if obj.get("auth") is not None
                else None,
            }
        )
        return _obj
