# coding: utf-8

# flake8: noqa
"""
Earnix Elevate Relay API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

# import models into model package
from earnix_elevate.clients.relay.models.problem_detail import ProblemDetail
