# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
import re
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictInt, constr, validator


class SourceNodeDefinition(BaseModel):
    """
    `SourceNodeDefinition`

    Defines a source node and its alias binding for a recipe node
    """

    source_node_id: StrictInt = Field(
        default=...,
        alias="sourceNodeId",
        description="ID of the source node in the transformation graph",
    )
    alias: Optional[constr(strict=True, max_length=64, min_length=1)] = Field(
        default=None,
        description='Alias for this source. Optional for single-source recipes (defaults to "CurrentTable"). Required for multi-source recipes (must match one of the recipe\'s aliases). ',
    )
    __properties = ["sourceNodeId", "alias"]

    @validator("alias")
    def alias_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[a-zA-Z][a-zA-Z0-9_]*$", value):
            raise ValueError(
                r"must validate the regular expression /^[a-zA-Z][a-zA-Z0-9_]*$/"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SourceNodeDefinition:
        """Create an instance of SourceNodeDefinition from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SourceNodeDefinition:
        """Create an instance of SourceNodeDefinition from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SourceNodeDefinition.parse_obj(obj)

        _obj = SourceNodeDefinition.parse_obj(
            {"source_node_id": obj.get("sourceNodeId"), "alias": obj.get("alias")}
        )
        return _obj
