# coding: utf-8

"""
Earnix Elevate Umon API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from datetime import datetime
from typing import Optional

from pydantic.v1 import (
    BaseModel,
    Field,
    StrictBool,
    StrictInt,
    StrictStr,
    conlist,
    constr,
)


class CreateQuotaRequest(BaseModel):
    """
    `CreateQuotaRequest`

    Request to create a new quota contract
    """

    name: Optional[constr(strict=True, max_length=100, min_length=3)] = Field(
        default=None,
        description="Name of the entity for identification and display purposes",
    )
    description: Optional[constr(strict=True, max_length=500)] = Field(
        default=None,
        description="Optional detailed description providing additional context about the entity",
    )
    tags: Optional[conlist(StrictStr, unique_items=True)] = Field(
        default=None,
        description="List of unique tags for categorizing and organizing the entity",
    )
    start_date: Optional[datetime] = Field(
        default=None,
        alias="startDate",
        description="Start date of quota contract (inclusive)",
    )
    end_date: Optional[datetime] = Field(
        default=None,
        alias="endDate",
        description="End date of quota contract (exclusive)",
    )
    cpu_time_hours: Optional[StrictInt] = Field(
        default=None, alias="cpuTimeHours", description="CPU hours quota"
    )
    data_transfer_gb: Optional[StrictInt] = Field(
        default=None, alias="dataTransferGb", description="Data transfer quota in GB"
    )
    overage_allowed: Optional[StrictBool] = Field(
        default=None,
        alias="overageAllowed",
        description="Whether overage beyond quota is allowed",
    )
    __properties = [
        "name",
        "description",
        "tags",
        "startDate",
        "endDate",
        "cpuTimeHours",
        "dataTransferGb",
        "overageAllowed",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateQuotaRequest:
        """Create an instance of CreateQuotaRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict["description"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateQuotaRequest:
        """Create an instance of CreateQuotaRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateQuotaRequest.parse_obj(obj)

        _obj = CreateQuotaRequest.parse_obj(
            {
                "name": obj.get("name"),
                "description": obj.get("description"),
                "tags": obj.get("tags"),
                "start_date": obj.get("startDate"),
                "end_date": obj.get("endDate"),
                "cpu_time_hours": obj.get("cpuTimeHours"),
                "data_transfer_gb": obj.get("dataTransferGb"),
                "overage_allowed": obj.get("overageAllowed"),
            }
        )
        return _obj
