# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint

from pydantic.v1 import Field

from earnix_elevate.clients.imx.models.delta_sharing_auth_request import (
    DeltaSharingAuthRequest,
)
from earnix_elevate.clients.imx.models.test_connection_request import (
    TestConnectionRequest,
)


class TestDeltaSharingConnectionRequest(TestConnectionRequest):
    """
    `TestDeltaSharingConnectionRequest`

    Request to test an DeltaSharing Connection by attempting to authenticate and access the DeltaSharing service using the provided credentials and endpoint configuration.
    """

    auth: DeltaSharingAuthRequest = Field(...)
    __properties = ["type", "auth"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TestDeltaSharingConnectionRequest:
        """Create an instance of TestDeltaSharingConnectionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of auth
        if self.auth:
            _dict["auth"] = self.auth.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TestDeltaSharingConnectionRequest:
        """Create an instance of TestDeltaSharingConnectionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TestDeltaSharingConnectionRequest.parse_obj(obj)

        _obj = TestDeltaSharingConnectionRequest.parse_obj(
            {
                "type": obj.get("type"),
                "auth": DeltaSharingAuthRequest.from_dict(obj.get("auth"))
                if obj.get("auth") is not None
                else None,
            }
        )
        return _obj
