# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictInt, conlist, constr


class UpdateRecipeVersionRequest(BaseModel):
    """
    `UpdateRecipeVersionRequest`

    Updates version-specific code (can only update if version is NOT locked)
    """

    code: constr(strict=True, min_length=8) = Field(
        default=..., description="SQL code that defines the data transformation logic"
    )
    version_number: StrictInt = Field(
        default=...,
        alias="versionNumber",
        description="Recipe version number (current version used by this node)",
    )
    aliases: Optional[
        conlist(
            constr(strict=True, max_length=64, min_length=1), max_items=10, min_items=1
        )
    ] = Field(
        default=None,
        description='Table aliases used in SQL code for recipe transformations. Single-source recipes have 1 alias (e.g. "CurrentTable" for backward compatibility, or any valid name). Multi-source recipes have 2-10 aliases matching table names in SQL. ',
    )
    lock_version: StrictInt = Field(
        default=..., alias="lockVersion", description="Optimistic locking version"
    )
    __properties = ["code", "versionNumber", "aliases", "lockVersion"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdateRecipeVersionRequest:
        """Create an instance of UpdateRecipeVersionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdateRecipeVersionRequest:
        """Create an instance of UpdateRecipeVersionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UpdateRecipeVersionRequest.parse_obj(obj)

        _obj = UpdateRecipeVersionRequest.parse_obj(
            {
                "code": obj.get("code"),
                "version_number": obj.get("versionNumber"),
                "aliases": obj.get("aliases"),
                "lock_version": obj.get("lockVersion"),
            }
        )
        return _obj
