# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictBool, StrictInt, StrictStr


class DatasetVersionUsage(BaseModel):
    """
    `DatasetVersionUsage`

    Information about how a recipe version is used in a specific dataset version
    """

    dataset_id: Optional[StrictInt] = Field(
        default=None, alias="datasetId", description="Unique identifier of the Dataset"
    )
    dataset_name: Optional[StrictStr] = Field(
        default=None, alias="datasetName", description="Name of the Dataset"
    )
    dataset_version_number: Optional[StrictInt] = Field(
        default=None,
        alias="datasetVersionNumber",
        description="Version number of the Dataset transformation graph",
    )
    release_status: Optional[StrictBool] = Field(
        default=None,
        alias="releaseStatus",
        description="Indicates whether this transformation graph version has been released for production use",
    )
    node_id: Optional[StrictStr] = Field(
        default=None,
        alias="nodeId",
        description="Unique identifier of the recipe node within this dataset version",
    )
    __properties = [
        "datasetId",
        "datasetName",
        "datasetVersionNumber",
        "releaseStatus",
        "nodeId",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DatasetVersionUsage:
        """Create an instance of DatasetVersionUsage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DatasetVersionUsage:
        """Create an instance of DatasetVersionUsage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DatasetVersionUsage.parse_obj(obj)

        _obj = DatasetVersionUsage.parse_obj(
            {
                "dataset_id": obj.get("datasetId"),
                "dataset_name": obj.get("datasetName"),
                "dataset_version_number": obj.get("datasetVersionNumber"),
                "release_status": obj.get("releaseStatus"),
                "node_id": obj.get("nodeId"),
            }
        )
        return _obj
