# coding: utf-8

"""
Earnix Elevate Umon API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint

from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr, validator


class UsageMonitoringResponse(BaseModel):
    """
    `UsageMonitoringResponse`

    Aggregated usage metrics for a tenant
    """

    metric_type: StrictStr = Field(
        default=..., alias="metricType", description="Type of usage metric"
    )
    total_value: StrictInt = Field(
        default=...,
        alias="totalValue",
        description="Total aggregated metric value across all jobs",
    )
    __properties = ["metricType", "totalValue"]

    @validator("metric_type")
    def metric_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in (
            "DATA_TRANSFER_VOLUME_BYTES",
            "CPU_TIME_MS",
        ):
            raise ValueError(
                "must be one of enum values ('DATA_TRANSFER_VOLUME_BYTES', 'CPU_TIME_MS')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UsageMonitoringResponse:
        """Create an instance of UsageMonitoringResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UsageMonitoringResponse:
        """Create an instance of UsageMonitoringResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UsageMonitoringResponse.parse_obj(obj)

        _obj = UsageMonitoringResponse.parse_obj(
            {"metric_type": obj.get("metricType"), "total_value": obj.get("totalValue")}
        )
        return _obj
