# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint

from pydantic.v1 import Field

from earnix_elevate.clients.imx.models.o_auth_request import OAuthRequest
from earnix_elevate.clients.imx.models.update_connection_request import (
    UpdateConnectionRequest,
)


class UpdatePriceItDimConnectionRequest(UpdateConnectionRequest):
    """
    `UpdatePriceItDimConnectionRequest`

    Request to update a Price-it DIM Connection, allowing modification of authentication credentials.
    """

    auth: OAuthRequest = Field(...)
    __properties = ["id", "lockVersion", "name", "description", "tags", "type", "auth"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdatePriceItDimConnectionRequest:
        """Create an instance of UpdatePriceItDimConnectionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of auth
        if self.auth:
            _dict["auth"] = self.auth.to_dict()
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict["description"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdatePriceItDimConnectionRequest:
        """Create an instance of UpdatePriceItDimConnectionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UpdatePriceItDimConnectionRequest.parse_obj(obj)

        _obj = UpdatePriceItDimConnectionRequest.parse_obj(
            {
                "id": obj.get("id"),
                "lock_version": obj.get("lockVersion"),
                "name": obj.get("name"),
                "description": obj.get("description"),
                "tags": obj.get("tags"),
                "type": obj.get("type"),
                "auth": OAuthRequest.from_dict(obj.get("auth"))
                if obj.get("auth") is not None
                else None,
            }
        )
        return _obj
