# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field

from earnix_elevate.clients.data.models.job_error import JobError
from earnix_elevate.clients.data.models.job_progress import JobProgress
from earnix_elevate.clients.data.models.job_status import JobStatus


class JobExecution(BaseModel):
    """
    `JobExecution`

    Job execution status, progress, and error information. Reusable across all job types.
    """

    status: JobStatus = Field(...)
    progress: Optional[JobProgress] = None
    error: Optional[JobError] = None
    __properties = ["status", "progress", "error"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> JobExecution:
        """Create an instance of JobExecution from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of progress
        if self.progress:
            _dict["progress"] = self.progress.to_dict()
        # override the default output from pydantic by calling `to_dict()` of error
        if self.error:
            _dict["error"] = self.error.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> JobExecution:
        """Create an instance of JobExecution from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return JobExecution.parse_obj(obj)

        _obj = JobExecution.parse_obj(
            {
                "status": obj.get("status"),
                "progress": JobProgress.from_dict(obj.get("progress"))
                if obj.get("progress") is not None
                else None,
                "error": JobError.from_dict(obj.get("error"))
                if obj.get("error") is not None
                else None,
            }
        )
        return _obj
