# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json

from aenum import Enum


class JobStatus(str, Enum):
    """
    `JobStatus`

    Job status common to all job types
    """

    """
    allowed enum values
    """
    PENDING = "PENDING"
    SUBMITTED = "SUBMITTED"
    RUNNING = "RUNNING"
    SUCCEEDED = "SUCCEEDED"
    FAILED = "FAILED"
    CANCELLED = "CANCELLED"

    @classmethod
    def from_json(cls, json_str: str) -> JobStatus:
        """Create an instance of JobStatus from a JSON string"""
        return JobStatus(json.loads(json_str))
